#[non_exhaustive]pub struct Animate<T, U: Clone> {
pub subtree: T,
pub animation: Animation,
pub frame_time: Duration,
pub value: U,
pub is_partial: bool,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subtree: Tanimation: AnimationLength of the animation
frame_time: DurationThe time at which this frame was generated
value: Uis_partial: boolThis is true if the animation is the result of a partially-completed join operation. If this is true, the source animation / duration will be used if the values are equal to avoid animations cancelling.
Implementations