pub struct LayerHandle<'a, C> { /* private fields */ }Expand description
Provides a safe abstraction for modifying a layer configuration.
Implementations
Sourceimpl<'a, C: Interpolate + Copy> LayerHandle<'a, C>
impl<'a, C: Interpolate + Copy> LayerHandle<'a, C>
Sourcepub fn new(layer: &'a mut LayerConfig<C>) -> Self
pub fn new(layer: &'a mut LayerConfig<C>) -> Self
Creates a new layer handle for the given layer configuration.
Sourcepub fn opacity(self, opacity: u8) -> Self
pub fn opacity(self, opacity: u8) -> Self
Sets the layer opacity.
Depending on the render target, a background color hint may need to be set to see the effect of the opacity.
See: [hint_background]
Sourcepub fn hint_background(self, color: C) -> Self
pub fn hint_background(self, color: C) -> Self
Sets a background color hint for the layer.
This is used to simulate alpha blending by interpolating the background color with the specified color based on the layer’s alpha value.
pub fn transform(self, transform: &LinearTransform) -> Self
pub fn offset(self, offset: Point) -> Self
pub fn scale(self, scale: ScaleFactor) -> Self
pub fn clip(self, clip_rect: &Rectangle) -> Self